@@ -28,7 +28,6 @@ import fasteners
 from oslo_config import cfg
 from oslo_utils import reflection
 from oslo_utils import timeutils
-import six
 
 from oslo_concurrency._i18n import _
 
@@ -281,6 +280,37 @@ def lock(name, lock_file_prefix=None, external=False, lock_path=None,
                 LOG.debug('Releasing lock "%(lock)s"', {'lock': name})
 
 
+def lock_with_prefix(lock_file_prefix):
+    """Partial object generator for the lock context manager.
+
+    Redefine lock in each project like so::
+
+        (in nova/utils.py)
+        from oslo_concurrency import lockutils
+
+        _prefix = 'nova'
+        lock = lockutils.lock_with_prefix(_prefix)
+        lock_cleanup = lockutils.remove_external_lock_file_with_prefix(_prefix)
+
+
+        (in nova/foo.py)
+        from nova import utils
+
+        with utils.lock('mylock'):
+           ...
+
+    Eventually clean up with::
+
+        lock_cleanup('mylock')
+
+    :param lock_file_prefix: A string used to provide lock files on disk with a
+        meaningful prefix. Will be separated from the lock name with a hyphen,
+        which may optionally be included in the lock_file_prefix (e.g.
+        ``'nova'`` and ``'nova-'`` are equivalent).
+    """
+    return functools.partial(lock, lock_file_prefix=lock_file_prefix)
+
+
 def synchronized(name, lock_file_prefix=None, external=False, lock_path=None,
                  semaphores=None, delay=0.01, fair=False):
     """Synchronization decorator.
@@ -311,7 +341,7 @@ def synchronized(name, lock_file_prefix=None, external=False, lock_path=None,
 
     def wrap(f):
 
-        @six.wraps(f)
+        @functools.wraps(f)
         def inner(*args, **kwargs):
             t1 = timeutils.now()
             t2 = None
@@ -350,7 +380,9 @@ def synchronized_with_prefix(lock_file_prefix):
         (in nova/utils.py)
         from oslo_concurrency import lockutils
 
-        synchronized = lockutils.synchronized_with_prefix('nova-')
+        _prefix = 'nova'
+        synchronized = lockutils.synchronized_with_prefix(_prefix)
+        lock_cleanup = lockutils.remove_external_lock_file_with_prefix(_prefix)
 
 
         (in nova/foo.py)
@@ -360,8 +392,14 @@ def synchronized_with_prefix(lock_file_prefix):
         def bar(self, *args):
            ...
 
-    The lock_file_prefix argument is used to provide lock files on disk with a
-    meaningful prefix.
+    Eventually clean up with::
+
+        lock_cleanup('mylock')
+
+    :param lock_file_prefix: A string used to provide lock files on disk with a
+        meaningful prefix. Will be separated from the lock name with a hyphen,
+        which may optionally be included in the lock_file_prefix (e.g.
+        ``'nova'`` and ``'nova-'`` are equivalent).
     """
 
     return functools.partial(synchronized, lock_file_prefix=lock_file_prefix)
@@ -375,18 +413,25 @@ def remove_external_lock_file_with_prefix(lock_file_prefix):
         (in nova/utils.py)
         from oslo_concurrency import lockutils
 
-        synchronized = lockutils.synchronized_with_prefix('nova-')
-        synchronized_remove = lockutils.remove_external_lock_file_with_prefix(
-            'nova-')
+        _prefix = 'nova'
+        synchronized = lockutils.synchronized_with_prefix(_prefix)
+        lock = lockutils.lock_with_prefix(_prefix)
+        lock_cleanup = lockutils.remove_external_lock_file_with_prefix(_prefix)
 
         (in nova/foo.py)
         from nova import utils
 
         @utils.synchronized('mylock')
         def bar(self, *args):
-           ...
+            ...
 
-        <eventually call synchronized_remove('mylock') to cleanup>
+        def baz(self, *args):
+            ...
+            with utils.lock('mylock'):
+                ...
+            ...
+
+        <eventually call lock_cleanup('mylock') to clean up>
 
     The lock_file_prefix argument is used to provide lock files on disk with a
     meaningful prefix.
